==> js-language-24.0.1-sources.jar: com/oracle/truffle/js/runtime/builtins/temporal/JSTemporalPrecisionRecord.java <==
/*
 * Copyright (c) 2021, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.js.runtime.builtins.temporal;

import com.oracle.truffle.js.runtime.util.TemporalUtil.Unit;

public final class JSTemporalPrecisionRecord {
    private final Object precision; // number, or TruffleString "auto"
    private final Unit unit;
    private final double increment;

    private JSTemporalPrecisionRecord(Object precision, Unit unit, double increment) {
        this.precision = precision;
        this.unit = unit;
        this.increment = increment;
    }

    public static JSTemporalPrecisionRecord create(Object precision, Unit unit, double increment) {
        return new JSTemporalPrecisionRecord(precision, unit, increment);
    }

    public Object getPrecision() {
        return precision;
    }

    public Unit getUnit() {
        return unit;
    }

    public double getIncrement() {
        return increment;
    }
}

==> js-language-24.1.2-sources.jar: com/oracle/truffle/js/runtime/builtins/temporal/JSTemporalPrecisionRecord.java <==
/*
 * Copyright (c) 2021, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.js.runtime.builtins.temporal;

import com.oracle.truffle.api.strings.TruffleString;
import com.oracle.truffle.js.runtime.Strings;
import com.oracle.truffle.js.runtime.util.TemporalConstants;
import com.oracle.truffle.js.runtime.util.TemporalUtil.Unit;

public final class JSTemporalPrecisionRecord {
    private final Object precision; // TruffleString "minute", "auto", or an integer from 0 to 9
    private final Unit unit;
    private final int increment;

    private JSTemporalPrecisionRecord(Object precision, Unit unit, int increment) {
        assert isValidPrecision(precision) : precision;
        this.precision = precision;
        this.unit = unit;
        this.increment = increment;
    }

    public static JSTemporalPrecisionRecord create(Object precision, Unit unit, int increment) {
        return new JSTemporalPrecisionRecord(precision, unit, increment);
    }

    public Object getPrecision() {
        return precision;
    }

    public Unit getUnit() {
        return unit;
    }

    public int getIncrement() {
        return increment;
    }

    public static boolean isValidPrecision(Object precision) {
        if (precision instanceof TruffleString strPrecision) {
            return Strings.equals(strPrecision, TemporalConstants.MINUTE) || Strings.equals(strPrecision, TemporalConstants.AUTO);
        } else if (precision instanceof Integer intPrecision) {
            return (0 <= intPrecision) || (intPrecision <= 9);
        } else {
            return false;
        }
    }

}
